@@ -1,11 +1,15 @@
 # This file contains useful functions used across different plotting scripts.
-from re import T
+from re import A, T
 import warnings
 from .. import data as data_dir
+from cosmoglobe.sky.model import Model
+from cosmoglobe.h5.model import model_from_chain
+from cosmoglobe.h5.chain import Chain
 
 import cmasher
 from rich import print
 import numpy as np
+import healpy as hp
 import matplotlib.pyplot as plt
 import astropy.units as u
 from matplotlib.colors import colorConverter, LinearSegmentedColormap, ListedColormap
@@ -14,13 +18,24 @@ from matplotlib import _pylab_helpers
 from pathlib import Path
 import json
 
+FIGURE_WIDTHS = {
+                    "x": 2.75,
+                    "s": 3.5,
+                    "m": 4.7,
+                    "l": 7,
+                }
+STOKES = [
+    "I",
+    "Q",
+    "U",
+]
 
 def apply_logscale(m, ticks, linthresh=1):
     """
     This function converts the data to logscale,
     and also converts the tick locations correspondingly
     """
-    print("[orange]Applying semi-logscale[/orange]")
+    print("[magenta]Applying semi-logscale[/magenta]")
     m = symlog(m, linthresh)
     new_ticks = []
     for i in ticks:
@@ -29,7 +44,6 @@ def apply_logscale(m, ticks, linthresh=1):
     m = np.maximum(np.minimum(m, new_ticks[-1]), new_ticks[0])
     return m, new_ticks
 
-
 def set_style(
     darkmode=False,
 ):
@@ -60,21 +74,22 @@ def set_style(
     )
 
     ## If darkmode plot (white frames), change colors:
+    params = [
+        "text.color",
+        "axes.edgecolor",
+        "axes.labelcolor",
+        "xtick.color",
+        "ytick.color",
+        "grid.color",
+        "legend.facecolor",
+        "legend.edgecolor",
+    ]
     if darkmode:
-        params = [
-            "text.color",
-            "axes.facecolor",
-            "axes.edgecolor",
-            "axes.labelcolor",
-            "xtick.color",
-            "ytick.color",
-            "grid.color",
-            "legend.facecolor",
-            "legend.edgecolor",
-        ]
         for p in params:
             plt.rcParams[p] = "white"
-
+    else:
+        for p in params:
+            plt.rcParams[p] = "black"
 
 def make_fig(
     figsize,
@@ -139,7 +154,6 @@ def make_fig(
 
     return fig, ax
 
-
 def load_cmap(
     cmap,
 ):
@@ -207,7 +221,6 @@ def load_cmap(
     # print("Colormap:" + f" {cmap.name}")
     return cmap
 
-
 def get_percentile(m, percentile):
     """
     This function gets appropriate min and max
@@ -220,7 +233,6 @@ def get_percentile(m, percentile):
     vmax = 0.0 if abs(vmax) < 1e-5 else vmax
     return [vmin, vmax]
 
-
 def fmt(x, pos):
     """
     Format color bar labels
@@ -240,6 +252,8 @@ def fmt(x, pos):
         x = round(x, 2)
         return fr"${x}$"
 
+def format_list(items):
+    return [fmt(i, 1) for i in items]
 
 def symlog(m, linthresh=1.0):
     """
@@ -249,9 +263,8 @@ def symlog(m, linthresh=1.0):
     m = m / linthresh / (2 * np.log(10))
     return np.log10(0.5 * (m + np.sqrt(4.0 + m * m)))
 
-
 def autoparams(
-    comp, sig, right_label, left_label, unit, ticks, min, max, norm, cmap, freq
+    comp, sig, right_label, left_label, unit, ticks, min, max, rng, norm, cmap, freq
 ):
     """
     This parses the autoparams json file for automatically setting parameters
@@ -275,7 +288,7 @@ def autoparams(
         try:
             params = autoparams[comp]
         except:
-            print(f"[orange]Component label {comp} not found. Using unidentified profile.[/orange]")
+            print(f"[magenta]Component label {comp} not found. Using unidentified profile.[/magenta]")
             print(f"available keys are: {autoparams.keys()}")
             params = autoparams["unidentified"]
 
@@ -291,12 +304,18 @@ def autoparams(
 
         specials = ["residual", "freqmap", "bpcorr", "smap"]
         if any(j in comp for j in specials):
-            params["right_label"] = (
-                params["right_label"]
-                + "{"
-                + f'{("%.5f" % freq.value).rstrip("0").rstrip(".")}'
-                + "}"
-            )
+            if freq is not None:
+                params["right_label"] = (
+                    params["right_label"]
+                    + "{"
+                    + f'{("%.5f" % freq.value).rstrip("0").rstrip(".")}'
+                    + "}"
+                )
+            else:
+                params["right_label"] = None
+                warnings.warn(
+                    f'Specify frequency with -freq for automatic frequency labeling with the "freqmap" profile'
+                )
 
         if "rms" in comp:
             params["right_label"] += "^{\mathrm{RMS}}"
@@ -329,27 +348,31 @@ def autoparams(
             )
         if ticks == None:
             if (
-                freq != None
+                freq is not None
                 and params["freq_ref"] != freq.value
                 and comp not in specials
             ):
                 warnings.warn(
-                    f"[orange]Input frequency is different from reference, autosetting ticks[/orange]"
+                    f"Input frequency is different from reference, autosetting ticks"
                 )
                 print(f'input: {freq}, reference: {params["freq_ref"]}')
                 params["ticks"] = "auto"
 
     if params["ticks"] is None:
         params["ticks"] = [min, max]
+    
     if ticks != "auto":
-        if min is not None:
-            if params["ticks"] == "auto":
-                params["ticks"] = [None, None]
-            params["ticks"][0] = min
-        if max is not None:
-            if params["ticks"] == "auto":
-                params["ticks"] = [None, None]
-            params["ticks"][-1] = max
+        if rng is not None:
+            params["ticks"] = [-rng, 0.0, rng]
+        else:
+            if min is not None:
+                if params["ticks"] == "auto":
+                    params["ticks"] = [None, None]
+                params["ticks"][0] = min
+            if max is not None:
+                if params["ticks"] == "auto":
+                    params["ticks"] = [None, None]
+                params["ticks"][-1] = max
     # Math text in labels
     for i in [
         "right_label",
@@ -361,14 +384,13 @@ def autoparams(
                 params[i] = r"$" + params[i] + "$"
     return params
 
-
 def legend_positions(
     input,
 ):
     """
     Calculate position of labels to the right in plot...
     """
-    positions = input[:, -1]
+    positions = input[-1,:]
 
     def push(dpush):
         """
@@ -406,7 +428,6 @@ def legend_positions(
         pushings += 1
     return positions
 
-
 def gradient_fill(x, y, fill_color=None, ax=None, alpha=1.0, invert=False, **kwargs):
     """
     Plot a line with a linear alpha gradient filled beneath it.
@@ -461,7 +482,6 @@ def gradient_fill(x, y, fill_color=None, ax=None, alpha=1.0, invert=False, **kwa
     ax.autoscale(True)
     return line, im
 
-
 def gradient_fill_between(ax, x, y1, y2, color="#ffa15a", alpha=0.5):
     N = 100
     y = np.zeros((N, len(y1)))
@@ -473,8 +493,194 @@ def gradient_fill_between(ax, x, y1, y2, color="#ffa15a", alpha=0.5):
         ax.fill_between(x, y[i - 1], y[i], color=color, alpha=alpha[i], zorder=-10)
         ax.set_rasterization_zorder(-1)
 
-
 def find_nearest(array, value):
     array = np.asarray(array)
     idx = (np.abs(array - value)).argmin()
     return array[idx], idx
+
+def standalone_colorbar(cmap, ticks, ticklabels=None, unit=None, fontsize=None, norm=None, shrink=.3, darkmode=False, width=10):
+    set_style(darkmode)
+    if fontsize is None: fontsize=get_default_fontsize()
+    plt.figure(figsize=(width,2))
+    img = plt.imshow(np.array([[ticks[0],ticks[-1]]]), load_cmap(cmap))
+    plt.gca().set_visible(False)
+    if ticklabels is None: ticklabels = format_list(ticks)
+    apply_colorbar(plt.gcf(), plt.gca(), img, ticks, ticklabels, unit, fontsize=fontsize, norm=norm, shrink=shrink)
+    
+def apply_colorbar(
+    fig, ax, image, ticks, ticklabels, unit, fontsize=None, linthresh=1, norm=None, shrink=0.3
+):
+    """
+    This function applies a colorbar to the figure and formats the ticks.
+    """
+    from matplotlib.ticker import FuncFormatter
+
+    if fontsize is None: fontsize = get_default_fontsize()
+    cb = fig.colorbar(
+        image,
+        ax=ax,
+        orientation="horizontal",
+        shrink=shrink,
+        pad=0.04,
+        ticks=ticks,
+        format=FuncFormatter(fmt),
+    )
+    cb.ax.set_xticklabels(ticklabels, size=fontsize["cbar_tick_label"])
+    if isinstance(unit, u.UnitBase):
+        unit = unit.to_string("latex")
+    cb.ax.xaxis.set_label_text(unit, size=fontsize["cbar_label"])
+    if norm == "log":
+        linticks = np.linspace(-1, 1, 3) * linthresh
+        logmin = np.round(ticks[0])
+        logmax = np.round(ticks[-1])
+
+        logticks_min = -(10 ** np.arange(0, abs(logmin) + 1))
+        logticks_max = 10 ** np.arange(0, logmax + 1)
+        ticks_ = np.unique(np.concatenate((logticks_min, linticks, logticks_max)))
+        # cb.set_ticks(np.concatenate((ticks,symlog(ticks_))), []) # Set major ticks
+
+        logticks = symlog(ticks_, linthresh)
+        logticks = [x for x in logticks if x not in ticks]
+        cb.set_ticks(np.concatenate((ticks, logticks)))  # Set major ticks
+        cb.ax.set_xticklabels(ticklabels + [""] * len(logticks))
+
+        minorticks = np.linspace(-linthresh, linthresh, 5)
+        minorticks2 = np.arange(2, 10) * linthresh
+
+        for i in range(len(logticks_min)):
+            minorticks = np.concatenate((-(10 ** i) * minorticks2, minorticks))
+        for i in range(len(logticks_max)):
+            minorticks = np.concatenate((minorticks, 10 ** i * minorticks2))
+
+        minorticks = symlog(minorticks, linthresh)
+        minorticks = minorticks[(minorticks >= ticks[0]) & (minorticks <= ticks[-1])]
+        cb.ax.xaxis.set_ticks(minorticks, minor=True)
+
+    cb.ax.tick_params(
+        which="both",
+        axis="x",
+        direction="in",
+    )
+    cb.ax.xaxis.labelpad = 0
+    # workaround for issue with viewers, see colorbar docstring
+    cb.solids.set_edgecolor("face")
+    return cb
+
+def get_data(input, sig, comp, freq, fwhm, nside=None, sample=-1, ):
+    # Parsing component string
+    fwhm_=None
+    specparam = "amp"
+    if comp is not None:
+        comp, *specparam_ = comp.split()
+        if specparam_: specparam = specparam_[0]
+
+    # If map is string, read data
+    if isinstance(input, str):
+        # If string input, then read either hdf or fits
+        if input.endswith(".h5"):
+            if comp is None:
+                if freq is None:             
+                    print("[bold magenta]Warning! Neither frequency nor component selected. Plotting sky at 70GHz[/bold magenta]")
+                    freq=70*u.GHz
+                data = model_from_chain(input, components=comp, nside=nside, samples=sample)
+                comp = "freqmap"
+            else:
+                if freq is not None:
+                    # If frequency is specified, simulate sky with model.
+                    data = model_from_chain(input, components=comp, nside=nside, samples=sample)
+                else:
+                    chain = Chain(input,)
+                    lmax = chain.get(f'{comp}/{specparam}_lmax', samples=sample)
+                    alms = chain.get(f'{comp}/{specparam}_alm', samples=sample)
+                    fwhm_ = chain.parameters[comp]['fwhm']*u.arcmin
+                    nside_ = chain.parameters[comp]["nside"]
+                    pol = True if specparam == "amp" and alms.shape[0] == 3 else False
+                    data = hp.alm2map(alms, nside=nside_, fwhm=fwhm_.to(u.rad).value, lmax=lmax, pol=pol)
+
+        elif input.endswith(".fits"):
+            data = hp.read_map(input, field=sig)
+        else:
+            raise ValueError(
+                    "Input file must be .fits or .h5"
+                )
+    else:
+        data = input
+    
+    if isinstance(data, Model):
+        """
+        Get data from model object with frequency scaling
+        """
+        if comp is None:
+            if freq is None:
+                print("[bold magenta]Warning! Neither frequency nor component selected. Plotting sky at 70GHz[/bold magenta]")
+                comp = "freqmap"
+                freq=70*u.GHz
+            m = data(
+                freq,
+                fwhm=fwhm
+            )
+        else:
+            if specparam == "amp":
+                if freq is None:
+                    # Get map at reference frequency if freq not specified
+                    freq_ref = getattr(data, comp).freq_ref
+                    freq = freq_ref.value
+                    m = getattr(data, comp).amp
+                    if comp == "radio":
+                        m = getattr(data, comp)(freq_ref, fwhm=fwhm)
+                    try:
+                        freq = round(freq.squeeze()[sig], 5) * freq_ref.unit
+                    except IndexError:
+                        freq = round(freq, 5) * freq_ref.unit
+                else:
+                    # If freq is specified, scale with sky model
+                    m = getattr(data, comp)(freq, fwhm=fwhm)
+            else:
+                m = getattr(data, comp).spectral_parameters[specparam]
+
+                if len(m[sig]) == 1:
+                    warnings.warn(
+                        "Same value across the whole sky, mapping to array of length Npix"
+                    )
+                    m = np.full(hp.nside2npix(data.nside), m[sig])
+
+    elif isinstance(data, np.ndarray):
+        m = data
+        if m.ndim == 1 and sig>0:
+            print(f'[magenta]Input array is 1d, specified signal will only be used for labeling, make sure this is correct.[/magenta]')
+    else:
+        raise TypeError(
+            f"Type {type(data)} of data not supported"
+            f"Supports numpy array, cosmoglobe model object or fits file string"
+        )
+
+    # Make sure it is a 1d array
+    if m.ndim > 1:
+        m = m[sig]
+
+    # Convert astropy map to numpy array
+    if isinstance(m, u.Quantity):
+        m = m.value
+
+    # ud_grade map
+    if nside is not None and nside != hp.get_nside(m):
+        m = hp.ud_grade(m, nside)
+    
+    # Smooth map
+    if fwhm > 0.0 and fwhm_ is None:
+        m = hp.smoothing(m, fwhm.to(u.rad).value)
+
+    return m
+
+def get_default_fontsize():
+    return {
+            "xlabel": 11,
+            "ylabel": 11,
+            "xtick_label": 8,
+            "ytick_label": 8,
+            "title": 12,
+            "cbar_label": 11,
+            "cbar_tick_label": 9,
+            "left_label": 11,
+            "right_label": 11,
+        }
\ No newline at end of file
