@@ -1,28 +1,29 @@
-from copy import Error
-from multiprocessing import Value
-from logging import error
-
 import warnings
 import os
+
 from rich import print
 import healpy as hp
 import numpy as np
 import astropy.units as u
 import matplotlib.pyplot as plt
+
 from .plottools import *
 
 # Fix for macos openMP duplicate bug
 os.environ["KMP_DUPLICATE_LIB_OK"] = "True"
 
+
 @u.quantity_input(freq=u.Hz, fwhm=(u.arcmin, u.rad, u.deg))
 def plot(
     input,
+    *,
     sig=0,
     comp=None,
     freq=None,
     ticks=None,
     min=None,
     max=None,
+    rng=None,
     cbar=True,
     unit=None,
     fwhm=0.0 * u.arcmin,
@@ -62,7 +63,6 @@ def plot(
     phi_convention="counterclockwise",
     custom_xtick_labels=None,
     custom_ytick_labels=None,
-    **kwargs,
 ):
     """
     General plotting function for healpix maps.
@@ -98,6 +98,9 @@ def plot(
     max : float, optional
       The maximum range value. If specified, overwrites autodetector.
       default = None
+    rng : float, optional
+      Sets this value as min and max value. If specified, overwrites autodetector.
+      default = None
     cbar : bool, optional
         Toggles the colorbar
         cbar = True
@@ -188,23 +191,16 @@ def plot(
         override x-axis tick labels
     custom_ytick_labels : list
         override y-axis tick labels
-        kwargs : keywords
-      any additional keyword is passed to pcolormesh
     """
     # Pick sizes from size dictionary for page width plots
     if width is None:
         override_plot_properties = None
     else:
         try:
-            width = int(width)
-        except:
+            width = float(width)
+        except ValueError:
             if isinstance(width, str):
-                width = {
-                    "x": 2.75,
-                    "s": 3.5,
-                    "m": 4.7,
-                    "l": 7,
-                }[width]
+                width = FIGURE_WIDTHS[width]
         ratio = 0.63 if cbar else 0.5
         xsize = int((1000 / 8.5) * width)
         override_plot_properties = {
@@ -213,36 +209,16 @@ def plot(
         }
 
     if not fontsize:
-        fontsize = {
-            "xlabel": 11,
-            "ylabel": 11,
-            "xtick_label": 8,
-            "ytick_label": 8,
-            "title": 12,
-            "cbar_label": 11,
-            "cbar_tick_label": 9,
-            "left_label": 11,
-            "right_label": 11,
-        }
+        fontsize = get_default_fontsize()
     set_style(darkmode)
 
     # Translate sig to correct format
-    stokes = [
-        "I",
-        "Q",
-        "U",
-    ]
     if isinstance(sig, str):
-        sig = stokes.index(sig)
+        sig = STOKES.index(sig)
 
     # Get data
     m = get_data(input, sig, comp, freq, fwhm, nside=nside, sample=sample)
-
-    # ud_grade map
-    if nside is not None and nside != hp.get_nside(m):
-        m = hp.ud_grade(m, nside)
-    else:
-        nside = hp.get_nside(m)
+    nside = hp.get_nside(m)
 
     # Mask map
     if mask is not None:
@@ -251,7 +227,9 @@ def plot(
 
         m = hp.ma(m)
         if hp.get_nside(mask) != nside:
-            print("[orange]Input mask nside is different, ud_grading to output nside.[/orange]")
+            print(
+                "[magenta]Input mask nside is different, ud_grading to output nside.[/magenta]"
+            )
             mask = hp.ud_grade(mask, nside)
         m.mask = np.logical_not(mask)
 
@@ -261,13 +239,21 @@ def plot(
 
     # Remove mono/dipole
     if remove_dip:
-        m = hp.remove_dipole(m, gal_cut=30, copy=True, verbose=True)
+        m = hp.remove_dipole(
+            m,
+            gal_cut=30,
+            copy=True,
+        )
     if remove_mono:
-        m = hp.remove_monopole(m, gal_cut=30, copy=True, verbose=True)
+        m = hp.remove_monopole(
+            m,
+            gal_cut=30,
+            copy=True,
+        )
 
     # Fetching autoset parameters
     params = autoparams(
-        comp, sig, right_label, left_label, unit, ticks, min, max, norm, cmap, freq
+        comp, sig, right_label, left_label, unit, ticks, min, max, rng, norm, cmap, freq
     )
 
     # Ticks and ticklabels
@@ -287,14 +273,14 @@ def plot(
     params["ticks"] = ticks
 
     # Special case if dipole is detected in freqmap
-    if comp == "freqmap":
+    if comp == "freqmap" and min is None and max is None and rng is None:
         # if colorbar is super-saturated
         while len(m[abs(m) > ticks[-1]]) / hp.nside2npix(nside) > 0.7:
             ticks = [tick * 10 for tick in ticks]
-            print("[orange]Colormap saturated. Expanding color-range.[/orange]")
+            print("[magenta]Colormap saturated. Expanding color-range.[/magenta]")
 
     # Create ticklabels from final ticks
-    ticklabels = [fmt(i, 1) for i in ticks]
+    ticklabels = format_list(ticks)
 
     # Semi-log normalization
     if params["norm"] == "log":
@@ -347,7 +333,7 @@ def plot(
         )
         return ret, params
 
-    warnings.filterwarnings("ignore") # Healpy complains too much
+    warnings.filterwarnings("ignore")  # Healpy complains too much
     # Plot figure
     ret = hp.newvisufunc.projview(
         m,
@@ -379,7 +365,6 @@ def plot(
         phi_convention=phi_convention,
         custom_xtick_labels=custom_xtick_labels,
         custom_ytick_labels=custom_ytick_labels,
-        **kwargs,
     )
     if not return_only_data:
         # Remove color bar because of healpy bug
@@ -419,4 +404,3 @@ def plot(
         transform=plt.gca().transAxes,
     )
     return ret, params
-
